@@ -1,17 +1,17 @@
 use strict;
 use warnings;
-package Dist::Zilla::Role::RepoFileInjector; # git description: v0.004-2-g8763068
+package Dist::Zilla::Role::RepoFileInjector; # git description: v0.005-4-ge3a0ed4
 # ABSTRACT: Create files outside the build directory
 # KEYWORDS: plugin distribution generate create file repository
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 
 use Moose::Role;
 
 use MooseX::Types qw(enum role_type);
 use MooseX::Types::Moose qw(ArrayRef Str Bool);
-use Path::Tiny;
+use Path::Tiny 0.022;
 use Cwd ();
 use namespace::clean;
 
@@ -92,12 +92,14 @@ sub write_repo_files
         }
         $self->log_fatal([ '%s already exists (allow_overwrite = 0)', $abs_filename ]) if -e $abs_filename;
 
-        # sadly, _write_out_file does $build_root->subdir without casting first
-        my $root = Path::Class::dir($filename->is_relative ? $self->repo_root : '');
-
         $self->log_debug([ 'writing out %s%s', $file->name,
-                $filename->is_relative ? ' to ' . $self->repo_root : '' ]);
-        $self->zilla->_write_out_file($file, $root);
+            $filename->is_relative ? ' to ' . $self->repo_root : '' ]);
+
+        Carp::croak("attempted to write $filename multiple times") if -e $filename;
+        $filename->touchpath;
+
+        $filename->spew_raw($file->encoded_content);
+        chmod $file->mode, "$filename" or die "couldn't chmod $filename: $!";
     }
 }
 
@@ -115,10 +117,16 @@ Dist::Zilla::Role::RepoFileInjector - Create files outside the build directory
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
+In your F<dist.ini>:
+
+    [MyPlugin]
+
+And in your plugin:
+
     package Dist::Zilla::Plugin::MyPlugin;
     use Moose;
     with 'Dist::Zilla::Role::RepoFileInjector';
@@ -145,6 +153,8 @@ the distribution.
 A string indicating the base directory where the file(s) are written, when
 relative paths are provided. Defaults to the current working directory.
 
+This attribute is available as an option of your plugin in F<dist.ini>.
+
 =head2 allow_overwrite
 
 A boolean indicating whether it is permissible for the file to already exist
@@ -153,6 +163,8 @@ the file already exists.
 
 Defaults to true.
 
+This attribute is available as an option of your plugin in F<dist.ini>.
+
 =head1 METHODS
 
 =head2 add_repo_file
@@ -162,6 +174,7 @@ Defaults to true.
 Registers a file object to be written to disk.
 If the path is not absolute, it is treated as relative to C<repo_root>.
 The file should consume the L<Dist::Zilla::Role::File> role.
+Normally the consuming plugin would call this in the C<FileGatherer> phase.
 
 =head2 write_repo_files
 
@@ -180,6 +193,7 @@ phase, e.g.:
 =head2 _repo_files
 
 Returns the list of files added via C<add_repo_file>.
+Normally the consuming plugin would call this in the C<FileMunger> phase.
 
 =head1 SEE ALSO
 
@@ -200,7 +214,7 @@ There is also a mailing list available for users of this distribution, at
 L<http://dzil.org/#mailing-list>.
 
 There is also an irc channel available for users of this distribution, at
-irc://irc.perl.org/#distzilla.
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
 
 I am also usually active on irc, as 'ether' at C<irc.perl.org>.
 
